@@ -20,6 +20,10 @@ class Variable(float):
     def with_unit(self):
         return f"{self:.3f} {self.unit}"
 
+    @property
+    def name_val(self):
+        return f"{self.var_name}: {self.with_unit}"
+
     def __iadd__(self, other):
         return Variable(self + other, self.name)
 
